@@ -15,6 +15,8 @@ from django.utils.timezone import now
 from django.utils.translation import gettext_lazy as _
 from sentry_sdk import capture_message
 
+from leprikon.utils.calendar import TimeSlot
+
 from ..models.activities import (
     Activity,
     ActivityGroup,
@@ -930,6 +932,7 @@ class RegistrationForm(FormMixin, forms.ModelForm):
 
 class CourseRegistrationForm(RegistrationForm):
     periods = forms.ModelMultipleChoiceField(
+        label=_("periods"),
         queryset=SchoolYearPeriod.objects.all(),
         widget=CheckboxSelectMultipleBootstrap(),
     )
@@ -1009,6 +1012,17 @@ class OrderableRegistrationForm(RegistrationForm):
             "canceled_by",
         )
 
+    def clean(self) -> dict[str, Any] | None:
+        self.cleaned_data = super().clean()
+        if "start_date" in self.cleaned_data and "start_time" in self.cleaned_data:
+            start = datetime.combine(self.cleaned_data["start_date"], self.cleaned_data["start_time"])
+            end: datetime = start + self.instance.activity.orderable.duration
+            timeslot = TimeSlot(start=start, end=end)
+            conflicting_timeslots = self.instance.activity_variant.get_conflicting_timeslots(start.date(), end.date())
+            if timeslot & conflicting_timeslots:
+                self.add_error("start_time", _("This time is not available."))
+        return self.cleaned_data
+
     @transaction.atomic
     def save(self, commit=True):
         start = datetime.combine(self.cleaned_data["start_date"], self.cleaned_data["start_time"])
