@@ -1,9 +1,8 @@
 from collections import namedtuple
-from datetime import date, datetime, timedelta
+from datetime import date, timedelta
 
 from cms.models import CMSPlugin
 from django.db import models
-from django.utils.formats import date_format, time_format
 from django.utils.functional import cached_property
 from django.utils.translation import gettext_lazy as _
 
@@ -118,13 +117,13 @@ class OrderableRegistration(Registration):
                 self.payment_requested.date()
                 if self.activity.orderable.due_from_days is None
                 else max(
-                    self.start_date - timedelta(days=self.activity.orderable.due_from_days),
+                    self.calendar_event.start_date - timedelta(days=self.activity.orderable.due_from_days),
                     self.payment_requested.date(),
                 )
             ),
             due_date=self.payment_requested
             and max(
-                self.start_date - timedelta(days=self.activity.orderable.due_date_days),
+                self.calendar_event.start_date - timedelta(days=self.activity.orderable.due_date_days),
                 self.payment_requested.date() + timedelta(days=self.activity.orderable.min_due_date_days),
             ),
         )
@@ -133,25 +132,9 @@ class OrderableRegistration(Registration):
             self.save(update_fields=["cached_balance"])
         return payment_status
 
-    @attributes(admin_order_field="start_date", short_description=_("event date"))
-    def event_date(self):
-        return "{start}{separator}{end}".format(
-            start=(
-                date_format(datetime.combine(self.start_date, self.start_time), "SHORT_DATETIME_FORMAT")
-                if self.start_time
-                else date_format(self.start_date, "SHORT_DATE_FORMAT")
-            ),
-            separator=" - " if self.start_date != self.end_date or self.end_time is not None else "",
-            end=(
-                (time_format(self.end_time, "TIME_FORMAT") if self.end_time else "")
-                if self.start_date == self.end_date
-                else (
-                    date_format(datetime.combine(self.end_date, self.end_time), "SHORT_DATETIME_FORMAT")
-                    if self.end_time
-                    else date_format(self.end_date, "SHORT_DATE_FORMAT")
-                )
-            ),
-        )
+    @attributes(admin_order_field="calendar_event__start_date", short_description=_("event date"))
+    def event_date(self) -> str:
+        return self.calendar_event.event_time
 
 
 class OrderableDiscount(ActivityDiscount):
