@@ -3,6 +3,7 @@ from datetime import date, datetime, time, timedelta
 from typing import Optional
 
 from django.db import models
+from django.utils.formats import date_format
 from django.utils.functional import cached_property
 from django.utils.translation import gettext_lazy as _
 
@@ -52,17 +53,28 @@ class AbstractTime(StartEndMixin, models.Model):
 
     def __str__(self):
         if self.start_time is not None and self.end_time is not None:
-            return _("{days}, {time}").format(
+            time_part = _("{days}, {time}").format(
                 days=self.days_of_week,
                 time=time_slot_format(self.start_time, self.end_time),
             )
         elif self.start_time is not None:
-            return _("{days}, {time}").format(
+            time_part = _("{days}, {time}").format(
                 days=self.days_of_week,
                 time=self.start_time.strftime("%H:%M"),
             )
         else:
-            return str(self.days_of_week)
+            time_part = str(self.days_of_week)
+        start_date_part = (
+            str(_("from {start_date}").format(start_date=date_format(self.start_date, "SHORT_DATE_FORMAT")))
+            if self.start_date
+            else ""
+        )
+        end_date_part = (
+            str(_("to {end_date}").format(end_date=date_format(self.end_date, "SHORT_DATE_FORMAT")))
+            if self.end_date
+            else ""
+        )
+        return " ".join(filter(None, [time_part, start_date_part, end_date_part]))
 
     @property
     def weekly_time(self) -> WeeklyTime:
@@ -82,20 +94,16 @@ class AbstractTime(StartEndMixin, models.Model):
         else:
             return timedelta(0)
 
-    def get_next_time(self, now: date | datetime = None):
+    def get_next_time(self, now: date | datetime = None) -> Time | None:
         now = now or datetime.now()
-        now_day = now.isoweekday()
+        next_date = now.date() if isinstance(now, datetime) else now
         # If the start time is None or less than now, we want to move to the next day
-        force_next_day = isinstance(now, date) or self.start_time is None or self.start_time <= now.time()
-        if force_next_day:
-            now_day = (now_day + 1) % 7
-        daydelta = min((d.isoweekday() - now_day) % 7 for d in self.days_of_week)
-        if daydelta == 0 and force_next_day:
-            daydelta = 7
-        if isinstance(now, datetime):
-            next_date = now.date() + timedelta(daydelta)
-        else:
-            next_date = now + timedelta(daydelta)
+        if isinstance(now, date) or self.start_time is None or self.start_time <= now.time():
+            next_date += timedelta(1)
+        days_of_week_bitmap = self.days_of_week.int()
+        if days_of_week_bitmap:
+            while (1 << next_date.weekday()) & days_of_week_bitmap == 0:
+                next_date += timedelta(1)
         return Time(
             date=next_date,
             start=self.start_time,
@@ -105,14 +113,14 @@ class AbstractTime(StartEndMixin, models.Model):
 
 class TimesMixin:
     @cached_property
-    def all_times(self):
+    def all_times(self) -> list[AbstractTime]:
         return list(self.times.all())
 
     @attributes(short_description=_("times"))
-    def get_times_list(self):
+    def get_times_list(self) -> str:
         return comma_separated(self.all_times)
 
-    def get_next_time(self, now=None):
+    def get_next_time(self, now: date | datetime | None = None) -> Time | None:
         try:
             return min(t.get_next_time(now) for t in self.all_times)
         except ValueError:
