@@ -9,7 +9,7 @@ from django.urls import reverse
 from django.utils import formats, timezone
 from django.utils.functional import cached_property
 from django.utils.text import slugify
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django_pays.models import Payment as PaysPayment
 
 from ..conf import settings
@@ -100,7 +100,7 @@ class Transaction(PdfExportAndMailMixin, AbstractTransaction):
     )
     PAYMENTS = frozenset({PAYMENT_CASH, PAYMENT_BANK, PAYMENT_ONLINE, TRANSFER})
     RETURNS = frozenset({RETURN_CASH, RETURN_BANK, TRANSFER, DONATION_TRANSFER})
-    SUBJECTS = frozenset(PAYMENTS.union(RETURNS))
+    ACTIVITIES = frozenset(PAYMENTS.union(RETURNS))
     DONATIONS = frozenset({DONATION_CASH, DONATION_BANK, DONATION_ONLINE, DONATION_TRANSFER})
     BANKS = frozenset({PAYMENT_BANK, RETURN_BANK, DONATION_BANK})
     ONLINES = frozenset({PAYMENT_ONLINE, DONATION_ONLINE})
@@ -123,9 +123,9 @@ class Transaction(PdfExportAndMailMixin, AbstractTransaction):
     # not editable
     mail_sent = models.DateTimeField(_("mail sent"), editable=False, null=True)
 
-    # subject payment fields
+    # payment fields
     source_registration = models.ForeignKey(
-        "SubjectRegistration",
+        "Registration",
         blank=True,
         null=True,
         on_delete=models.PROTECT,
@@ -134,7 +134,7 @@ class Transaction(PdfExportAndMailMixin, AbstractTransaction):
         help_text=_("The payment will be deducted from this registration."),
     )
     target_registration = models.ForeignKey(
-        "SubjectRegistration",
+        "Registration",
         blank=True,
         null=True,
         on_delete=models.PROTECT,
@@ -173,7 +173,6 @@ class Transaction(PdfExportAndMailMixin, AbstractTransaction):
         PaysPayment,
         blank=True,
         editable=False,
-        limit_choices_to={"status": PaysPayment.REALIZED},
         null=True,
         on_delete=models.PROTECT,
         verbose_name=_("online payment"),
