@@ -4,7 +4,7 @@ from itertools import chain
 from django.template.response import TemplateResponse
 from django.urls import reverse_lazy as reverse
 from django.utils.functional import cached_property
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from ...forms.reports.debtors import DebtorsForm
 from ...models.courses import CourseRegistration
@@ -35,7 +35,7 @@ class ReportDebtorsView(FormView):
 
         for reg in chain.from_iterable(
             qs.filter(
-                subject__school_year=self.request.school_year,
+                activity__school_year=self.request.school_year,
                 approved__date__lte=context["date"],
             )
             .prefetch_related(
